@@ -6,7 +6,7 @@ from .get_Sv import get_Sv, get_active_dives
 from .help_fun import haversine, compute_c, alpha_FrancoisGarrison, tvg
 from .kml2 import get_kml_track
 from .log_update import getSatFile, sat2log
-from .meta_reader import raw2meta
+from .meta_reader import raw2meta_extract
 #from mission2nc import get_paths, get_cal_val, read_all_zonar, update_cal, get_data, get_mission, mission2csv, get_AllRoiCounts, get_missions, miss2nc, missions_to_nc
 from .plot3d import plot3d
 from .read_sat import read_sat, get_twilight_index
